#
# spec file for package remmina
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rversion 1.2.0.rcgit.13
Name:           remmina
Version:        1.2.0~rcgit.13
Release:        1.1
Summary:        Versatile Remote Desktop Client
License:        GPL-2.0+
Group:          Productivity/Networking/Other
Url:            http://remmina.sourceforge.net/
Source0:        https://github.com/FreeRDP/Remmina/archive/%{rversion}.tar.gz
Source1:        README.SUSE
BuildRequires:  cmake
BuildRequires:  ed
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(avahi-glib)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freerdp2) >= 2.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(spice-client-gtk-3.0)
BuildRequires:  pkgconfig(telepathy-glib)
BuildRequires:  pkgconfig(unique-1.0)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
BuildRequires:  pkgconfig(winpr2)
BuildRequires:  pkgconfig(xkbfile)
Recommends:     %{name}-lang = %{version}
Provides:       remmina-plugins-common = %{version}
Obsoletes:      remmina-plugins-common < 1.0.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# vte-2.90 has been dropped from newer releases
%if 0%{?suse_version} < 1315
BuildRequires:  pkgconfig(vte-2.90)
%else
BuildRequires:  pkgconfig(vte-2.91)
%endif

%description
Remmina is a remote desktop client written in GTK+, aiming to be useful for
system administrators and travellers, who need to work with lots of remote
computers in front of either large monitors or tiny netbooks. Remmina supports
multiple network protocols such as RDP, VNC, NX, XDMCP and SSH via separate
plugins in an integrated and consistant user interface.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
This package contains header files needed for developing plugins for
Remmina.

%package -n remmina-plugin-spice
Summary:        SPICE Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description -n remmina-plugin-spice
This package provides the SPICE protocol plugin for Remmina.

%package -n remmina-plugin-xdmcp
Summary:        XDMCP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description -n remmina-plugin-xdmcp
This package provides the XDMCP protocol plugin for Remmina.

%if %{with nx}
%package -n remmina-plugin-nx
Summary:        NX Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
# for nxproxy
Requires:       NX
Requires:       remmina = %{version}

%description -n remmina-plugin-nx
This package provides the NX protocol plugin for Remmina.
%endif

%package -n remmina-plugin-rdp
Summary:        RDP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       freerdp
Requires:       remmina = %{version}

%description -n remmina-plugin-rdp
This package provides the RDP protocol plugin for Remmina.

%package -n remmina-plugin-vnc
Summary:        VNC Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description -n remmina-plugin-vnc
This package provides the RDP protocol plugin for Remmina.

#%%package -n remmina-plugin-telepathy
#Summary:        Telepathy Protocol Plugin for Remmina
#Group:          Productivity/Networking/Other
#Requires:       remmina = %%{version}

#%%description -n remmina-plugin-telepathy
#This package provides the Telepathy plugin for Remmina.

%package -n remmina-plugins-gnome
Summary:        GNOME Plugins for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description -n remmina-plugins-gnome
This package provides the GNOME plugins for Remmina.

%lang_package

%prep
%setup -q -n Remmina-%{rversion}
cp -r %{SOURCE1} README.SUSE

%build
#TODO: When gh#FreeRDP/Remmina#714 is fixed enable TELEPATHY
%cmake \
	-DWITH_TELEPATHY=OFF

make %{?_smp_mflags}

%install
%cmake_install

%if %{without nx}
rm -f %{buildroot}%{_libdir}/remmina/plugins/remmina-plugin-nx.so \
    %{buildroot}%{_datadir}/icons/hicolor/*/emblems/remmina-nx.png
%endif

%suse_update_desktop_file %{name} Network RemoteAccess GTK

%find_lang %{name}

%if 0%{?suse_version} >= 1140
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n remmina-plugin-spice
%icon_theme_cache_post

%postun -n remmina-plugin-spice
%icon_theme_cache_postun

%post -n remmina-plugin-xdmcp
%icon_theme_cache_post

%postun -n remmina-plugin-xdmcp
%icon_theme_cache_postun

%if %{with nx}
%post -n remmina-plugin-nx
%icon_theme_cache_post

%postun -n remmina-plugin-nx
%icon_theme_cache_postun
%endif

%post -n remmina-plugin-rdp
%icon_theme_cache_post

%postun -n remmina-plugin-rdp
%icon_theme_cache_postun

%post  -n remmina-plugin-vnc
%icon_theme_cache_post

%postun -n remmina-plugin-vnc
%icon_theme_cache_postun

#%%post -n remmina-plugin-telepathy
#%%icon_theme_cache_post

#%%postun -n remmina-plugin-telepathy
#%%icon_theme_cache_postun
%endif

%files
%defattr(-,root,root)
%doc AUTHORS CHANGELOG.md LICENSE LICENSE.OpenSSL README.md README.SUSE
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/actions/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/emblems/remmina-sftp.png
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins/

%files lang -f %{name}.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files -n remmina-plugin-spice
%defattr(-,root,root)
%{_libdir}/remmina/plugins/remmina-plugin-spice.so
%{_datadir}/icons/hicolor/*/emblems/remmina-spice.png

%files -n remmina-plugin-xdmcp
%defattr(-,root,root)
%{_libdir}/remmina/plugins/remmina-plugin-xdmcp.so
%{_datadir}/icons/hicolor/*/emblems/remmina-xdmcp-ssh.png
%{_datadir}/icons/hicolor/*/emblems/remmina-xdmcp.png

%if %{with nx}
%files -n remmina-plugin-nx
%defattr(-,root,root)
%{_libdir}/remmina/plugins/remmina-plugin-nx.so
%{_datadir}/icons/hicolor/*/emblems/remmina-nx.png
%endif

%files -n remmina-plugin-rdp
%defattr(-,root,root)
%{_libdir}/remmina/plugins/remmina-plugin-rdp.so
%{_datadir}/icons/hicolor/*/emblems/remmina-rdp-ssh.png
%{_datadir}/icons/hicolor/*/emblems/remmina-rdp.png

%files -n remmina-plugin-vnc
%defattr(-,root,root)
%{_libdir}/remmina/plugins/remmina-plugin-vnc.so
%{_datadir}/icons/hicolor/*/emblems/remmina-vnc-ssh.png
%{_datadir}/icons/hicolor/*/emblems/remmina-vnc.png

#%%files -n remmina-plugin-telepathy
#%%defattr(-,root,root)
#%%{_libdir}/remmina/plugins/remmina-plugin-telepathy.so

%files -n remmina-plugins-gnome
%defattr(-,root,root)
%{_libdir}/remmina/plugins/remmina-plugins-gnome.so

%changelog
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.2.0.rcgit.13 as freerdp 1.0 isn't available anymore
- dropped patches:
  * remmina-close-ssh-tunnel-on-disconnect.patch
  * remmina-fix-desktop-file.patch
  * remmina-fix-fullscreen-with-multiple-monitors.patch
  * remmina-fix-install-paths.patch
  * remmina-fix-linker-issue.patch
  * remmina-fix-scrolling-in-vnc-plugin.patch
  * remmina-fix-window-resize.patch
  * remmina-gtk-2-22-support.patch
  * remmina-remove-inline-libvncserver.patch
  * remmina-vte-2.91-support.patch
* Tue Oct 13 2015 dimstar@opensuse.org
- openSUSE_Leap 42.1: also apply the patch for vte-2.91.
* Fri Sep  4 2015 dimstar@opensuse.org
- openSUSE Leap 42.1 (suse_version 1315) also has vte-2.91.
* Thu Jan 22 2015 gber@opensuse.org
- amend remmina-fix-install-paths.patch to fix the installation of
  headers (gh#FreeRDP/Remmina#292)
* Tue Oct  7 2014 gber@opensuse.org
- add remmina-vte-2.91-support.patch in order to support building
  against vte-2.91 for openSUSE >= 13.2
- rename README.SuSE to README.SUSE
* Tue Oct  7 2014 dmueller@suse.com
- fix build against Factory
* Sat Mar 23 2013 gber@opensuse.org
- enable TLS-support in VNC plugin (bnc#804320)
- add remmina-fix-scrolling-in-vnc-plugin.patch which fixes
  scrolling in the VNC plugin (backport from upstream git)
- add remmina-close-ssh-tunnel-on-disconnect.patch in order to
  close SSH tunnels on disconnect and avoid freezing (backport from
  upstream git)
- remmina-fix-window-resize.patch which fixes resizing the window
  (backport from upstream git)
- add remmina-fix-fullscreen-with-multiple-monitors.patch which
  fixes fullscreen mode with multiple monitors (backport from
  upstream git)
* Thu Aug 23 2012 gber@opensuse.org
- add missing dependency on gnutls
* Sat Aug 18 2012 gber@opensuse.org
- added remmina-remove-inline-libvncserver.patch in order to remove
  the inline copy of libvncserver (backport from upstream git)
* Mon Apr  2 2012 gber@opensuse.org
- use original tarball name to fix download check
* Mon Apr  2 2012 gber@opensuse.org
- disable the NX plugin by default
* Wed Mar 28 2012 gber@opensuse.org
- added separare patch remmina-fix-install-paths.patch in order to
  fix the installation paths
- specfile cleanup
- removed remmina-plugins-common, now provided by the main package
- split off -lang subpackage
* Wed Mar 21 2012 gankov@opensuse.org
- rewrote spec for using cmake
- merged with remmina-plugins into one source package (upstream
  now diestributes a single tarball with plugins)
- update to version 1.0.0
  + Main program design and functionality:
  * Switch to the CMake build system
  * Refactoring of code style
  * Changing file name convention
  + RDP protocol related:
  * Support for FreeRDP 1.0
  * Support for RemoteFX
  * Support for Network Level Authentication
  * Added certificate validation prompt
- added remmina-fix-linker-issue.patch which fixes a linking issue
  (backport from upstream git)
- added remmina-fix-desktop-file.patch which fixes the installation
  of the .desktop file (backport from upstream git)
- added remmina-gtk-2-22-support.patch in order to build on
  openSUSE 11.4 with GTK 2.22 as upstream requires 2.24+
* Thu Sep 29 2011 gber@opensuse.org
- libunique1 is available on Factory so use it
- do not recommend non-existent remmina-plugins
- add a note about plugins
* Thu Sep 29 2011 gber@opensuse.org
- change the pkgconfig(libssh) dependency to libssh-devel in the
  - devel subpackage
* Thu Sep 22 2011 gber@opensuse.org
- cleanup
  + added license/copyright header
  + improved description/summary
  + use SPDX license abbreviation
  + removed %%clean section
  + use the correct macros to update the icon/desktop file cache in
    %%post/%%postun
  + use pkgconfig symbols unconditionally (this can be handled
    at the project level)
  + removed empty NEWS
* Fri Apr  8 2011 lijewski.stefan@gmail.com
- spec cleanup, prepare to move X11:RemoteDesktop
* Mon Feb  7 2011 gav@qsolution.ru
- Update to version 0.9.3
  + Integrate scrolled window and fullscreen view modes into one button
  + Remove quick connect menu and consolidate the feature with Connection->New
  menu.
* Fri Nov  5 2010 michal.smrz@opensuse.cz
- Update to version 0.8.3
- Edited BuildRequires and Requires to match web pages
* Mon Sep 27 2010 michal.smrz@opensuse.cz
- merge with nilda package created by djs_core <admin@djscore.org>
* Mon Sep 27 2010 prusnak@opensuse.org
- spec cleanup
* Tue Sep 21 2010 lijewski.stefan@gmail.com
- initial package for openSUSE
